==> eiffelstudio-18.11.10.2592.tar: F_code/C3/ew148.c <==
/*
 * Code for class EW_EIFFEL_VALIDITY_ERROR
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew148.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_EIFFEL_VALIDITY_ERROR}.make */
void F172_1791 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLIU(3);
	
	RTEAA("make", 171, Current, 0, 2, 1846);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg2;
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {EW_EIFFEL_VALIDITY_ERROR}.validity_code */
EIF_REFERENCE F172_1792 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {EW_EIFFEL_VALIDITY_ERROR}.summary */
EIF_REFERENCE F172_1794 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Result);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLIU(4);
	
	RTEAA("summary", 171, Current, 1, 0, 1849);
	RTGC;
	RTHOOK(1);
	Result = RTMS32_EX_H("V\000\000\000a\000\000\000l\000\000\000i\000\000\000d\000\000\000i\000\000\000t\000\000\000y\000\000\000 \000\000\000e\000\000\000r\000\000\000r\000\000\000o\000\000\000r\000\000\000",14,1957253234);
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current);
	tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R4240[Dtype(tr1)-895])(RTCW(tr1));
	if ((EIF_BOOLEAN) !tb1) {
		RTHOOK(3);
		tr1 = RTMS32_EX_H(" \000\000\000i\000\000\000n\000\000\000 \000\000\000c\000\000\000l\000\000\000a\000\000\000s\000\000\000s\000\000\000 \000\000\000",10,533636896);
		F897_5794(RTCW(Result), tr1);
		RTHOOK(4);
		F897_5794(RTCW(Result), *(EIF_REFERENCE *)(Current));
	}
	RTHOOK(5);
	tr1 = RTMS32_EX_H(" \000\000\000c\000\000\000o\000\000\000d\000\000\000e\000\000\000 \000\000\000",6,1932525344);
	F897_5794(RTCW(Result), tr1);
	RTHOOK(6);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTHOOK(7);
		F897_5794(RTCW(Result), loc1);
	}
	RTHOOK(8);
	if (F171_1784(Current)) {
		RTHOOK(9);
		tr1 = RTMS32_EX_H(" \000\000\000a\000\000\000t\000\000\000 \000\000\000l\000\000\000i\000\000\000n\000\000\000e\000\000\000 \000\000\000",9,1997649184);
		F897_5794(RTCW(Result), tr1);
		RTHOOK(10);
		F897_5798(RTCW(Result), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_));
	}
	RTHOOK(11);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_EIFFEL_VALIDITY_ERROR}.is_equal */
EIF_BOOLEAN F172_1795 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTEAA("is_equal", 171, Current, 0, 1, 1850);
	RTGC;
	RTHOOK(1);
	Result = '\0';
	if (F171_1787(Current, arg1)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tb1 = F895_5707(RTCW(tr1), tr2);
		Result = tb1;
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_EIFFEL_VALIDITY_ERROR}.is_less */
EIF_BOOLEAN F172_1796 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTEAA("is_less", 171, Current, 0, 1, 1851);
	RTGC;
	RTHOOK(1);
	Result = '\01';
	tb1 = '\01';
	tr1 = *(EIF_REFERENCE *)(Current);
	tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
	tb2 = F895_5709(RTCW(tr1), tr2);
	if (!tb2) {
		tb2 = '\0';
		tr1 = *(EIF_REFERENCE *)(Current);
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
		tb3 = F895_5707(RTCW(tr1), tr2);
		if (tb3) {
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
			tb3 = F895_5709(RTCW(tr1), tr2);
			tb2 = tb3;
		}
		tb1 = tb2;
	}
	if (!tb1) {
		tb1 = '\0';
		tb2 = '\0';
		tr1 = *(EIF_REFERENCE *)(Current);
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
		tb3 = F895_5707(RTCW(tr1), tr2);
		if (tb3) {
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
			tb3 = F895_5707(RTCW(tr1), tr2);
			tb2 = tb3;
		}
		if (tb2) {
			ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_2_0_0_0_);
			tb1 = (EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_) < ti4_1);
		}
		Result = tb1;
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_EIFFEL_VALIDITY_ERROR}.matches_pattern */
EIF_BOOLEAN F172_1797 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTEAA("matches_pattern", 171, Current, 0, 1, 1852);
	RTGC;
	RTHOOK(1);
	Result = '\0';
	if (F171_1789(Current, arg1)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tb1 = F895_5707(RTCW(tr1), tr2);
		Result = tb1;
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit148 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C3/ew148.c <==
/*
 * Code for class EW_EIFFEL_VALIDITY_ERROR
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew148.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_EIFFEL_VALIDITY_ERROR}.make */
void F172_1791 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLIU(3);
	
	RTEAA("make", 171, Current, 0, 2, 1846);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg2;
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {EW_EIFFEL_VALIDITY_ERROR}.summary */
EIF_REFERENCE F172_1794 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Result);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLIU(4);
	
	RTEAA("summary", 171, Current, 1, 0, 1849);
	RTGC;
	RTHOOK(1);
	Result = RTMS32_EX_H("V\000\000\000a\000\000\000l\000\000\000i\000\000\000d\000\000\000i\000\000\000t\000\000\000y\000\000\000 \000\000\000e\000\000\000r\000\000\000r\000\000\000o\000\000\000r\000\000\000",14,1957253234);
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current);
	tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R4261[Dtype(RTCW(tr1))-895])(tr1);
	if ((EIF_BOOLEAN) !tb1) {
		RTHOOK(3);
		tr1 = RTMS32_EX_H(" \000\000\000i\000\000\000n\000\000\000 \000\000\000c\000\000\000l\000\000\000a\000\000\000s\000\000\000s\000\000\000 \000\000\000",10,533636896);
		F897_5815(RTCW(Result), tr1);
		RTHOOK(4);
		F897_5815(RTCW(Result), *(EIF_REFERENCE *)(Current));
	}
	RTHOOK(5);
	tr1 = RTMS32_EX_H(" \000\000\000c\000\000\000o\000\000\000d\000\000\000e\000\000\000 \000\000\000",6,1932525344);
	F897_5815(RTCW(Result), tr1);
	RTHOOK(6);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTHOOK(7);
		F897_5815(RTCW(Result), loc1);
	}
	RTHOOK(8);
	if (F171_1784(Current)) {
		RTHOOK(9);
		tr1 = RTMS32_EX_H(" \000\000\000a\000\000\000t\000\000\000 \000\000\000l\000\000\000i\000\000\000n\000\000\000e\000\000\000 \000\000\000",9,1997649184);
		F897_5815(RTCW(Result), tr1);
		RTHOOK(10);
		F897_5819(RTCW(Result), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_));
	}
	RTHOOK(11);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_EIFFEL_VALIDITY_ERROR}.is_equal */
EIF_BOOLEAN F172_1795 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTEAA("is_equal", 171, Current, 0, 1, 1850);
	RTGC;
	RTHOOK(1);
	Result = '\0';
	if (F171_1787(Current, arg1)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tb1 = F895_5728(RTCW(tr1), tr2);
		Result = tb1;
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_EIFFEL_VALIDITY_ERROR}.is_less */
EIF_BOOLEAN F172_1796 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTEAA("is_less", 171, Current, 0, 1, 1851);
	RTGC;
	RTHOOK(1);
	Result = '\01';
	tb1 = '\01';
	tr1 = *(EIF_REFERENCE *)(Current);
	tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
	tb2 = F895_5730(RTCW(tr1), tr2);
	if (!tb2) {
		tb2 = '\0';
		tr1 = *(EIF_REFERENCE *)(Current);
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
		tb3 = F895_5728(RTCW(tr1), tr2);
		if (tb3) {
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
			tb3 = F895_5730(RTCW(tr1), tr2);
			tb2 = tb3;
		}
		tb1 = tb2;
	}
	if (!tb1) {
		tb1 = '\0';
		tb2 = '\0';
		tr1 = *(EIF_REFERENCE *)(Current);
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
		tb3 = F895_5728(RTCW(tr1), tr2);
		if (tb3) {
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
			tb3 = F895_5728(RTCW(tr1), tr2);
			tb2 = tb3;
		}
		if (tb2) {
			ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_2_0_0_0_);
			tb1 = (EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_) < ti4_1);
		}
		Result = tb1;
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_EIFFEL_VALIDITY_ERROR}.matches_pattern */
EIF_BOOLEAN F172_1797 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTEAA("matches_pattern", 171, Current, 0, 1, 1852);
	RTGC;
	RTHOOK(1);
	Result = '\0';
	if (F171_1789(Current, arg1)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tb1 = F895_5728(RTCW(tr1), tr2);
		Result = tb1;
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit148 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
